summaryrefslogtreecommitdiffstats
path: root/Source/cmLocalKdevelopGenerator.h
diff options
context:
space:
mode:
authorBill Hoffman <bill.hoffman@kitware.com>2004-10-25 20:39:13 (GMT)
committerBill Hoffman <bill.hoffman@kitware.com>2004-10-25 20:39:13 (GMT)
commitccea94278be686283a1b19e4f700891a6774e3a6 (patch)
tree70596a1465ab6cffe3e0d92d5d77f9b7226a59d9 /Source/cmLocalKdevelopGenerator.h
parent5eda3799074f858f7790975b7a294374720177f7 (diff)
downloadCMake-ccea94278be686283a1b19e4f700891a6774e3a6.zip
CMake-ccea94278be686283a1b19e4f700891a6774e3a6.tar.gz
CMake-ccea94278be686283a1b19e4f700891a6774e3a6.tar.bz2
ENH: add some more comments
Diffstat (limited to 'Source/cmLocalKdevelopGenerator.h')
-rw-r--r--Source/cmLocalKdevelopGenerator.h18
1 files changed, 14 insertions, 4 deletions
diff --git a/Source/cmLocalKdevelopGenerator.h b/Source/cmLocalKdevelopGenerator.h
index 03eaeee..e8e7cb3 100644
--- a/Source/cmLocalKdevelopGenerator.h
+++ b/Source/cmLocalKdevelopGenerator.h
@@ -26,10 +26,15 @@ class cmTarget;
class cmSourceFile;
/** \class cmLocalKdevelopGenerator
* \brief Write a LocalUnix makefiles.
*
- * cmLocalKdevelopGenerator produces a LocalUnix makefile from its
- * member m_Makefile.
+ * cmLocalKdevelopGenerator produces a project file for KDevelop 3 (KDevelop > 3.1.1).
+ * The project is based on the "Custom Makefile based C/C++" project of KDevelop.
+ * Such a project consists of Unix Makefiles in the build directory together
+ * with a <your_project>.kdevelop project file, which contains the project settings
+ * and a <your_project>.kdevelop.filelist file, which lists the source files relative
+ * to the kdevelop project directory. The kdevelop project directory is the base
+ * source directory.
*/
class cmLocalKdevelopGenerator : public cmLocalUnixMakefileGenerator
{
@@ -51,11 +56,16 @@ protected:
/**
Create the foo.kdevelop file. This one calls MergeProjectFiles()
if it already exists, otherwise createNewProjectFile()
+ The project files will be created in \a outputDir (in the build tree), the kdevelop project
+ dir will be set to \a projectDir (in the source tree). \a cmakeFilePattern consists of a lists
+ of all cmake listfiles used by this CMakeLists.txt
*/
void CreateProjectFile(const std::string& outputDir, const std::string& projectDir,
const std::string& projectname, const std::string& executable,
const std::string& cmakeFilePattern);
- ///! Create the foo.kdevelop.filelist file, return false if it doesn't succeed
+ /** Create the foo.kdevelop.filelist file, return false if it doesn't succeed.
+ If the file already exists the contents will be merged.
+ */
bool CreateFilelistFile(const std::string& outputDir, const std::string& projectDir,
const std::string& projectname, std::string& cmakeFilePattern);
///! Reads the old foo.kdevelop line by line and only replaces the "important" lines
@@ -26,10 +26,15 @@ class cmTarget;
class cmSourceFile;
/** \class cmLocalKdevelopGenerator
- * \brief Write a LocalUnix makefiles.
+ * \brief Write Unix Makefiles accompanied by KDevelop3 project files.
*